@@ -37,19 +37,6 @@ should always return a tuple of (metric_average, metric_per_output).
 from functools import wraps
 
 import ants
-
-try:
-    import lpips_tf
-except ModuleNotFoundError as err:
-    raise ModuleNotFoundError(
-        """
-        LPIPS-TensorFlow required but not found.
-
-        Please install it by running the following command:
-        $ pip install git+http://github.com/alexlee-gk/lpips-tensorflow.git#egg=lpips_tf
-        """
-    ) from err
-
 import numpy as np
 import pandas as pd
 import tensorflow as tf
@@ -798,7 +785,7 @@ def psnr_img(y_true, y_pred, mask=None, data_range=None):
 
     References
     ----------
-    .. [1] https://en.wikipedia.org/wiki/Peak_signal-to-noise_ratio
+    .. https://en.wikipedia.org/wiki/Peak_signal-to-noise_ratio
 
     """
     if mask is None:
@@ -996,17 +983,29 @@ def perceptual_loss_img(y_true, y_pred, model="net-lin", net="vgg"):
     We use the decorator just to make sure we do not run out of memory during a forward pass. Also,
     its fully convolutional but if the images are too small then might run into issues.
     """
+    try:
+        import lpips_tf
+    except ModuleNotFoundError as err:
+        raise ModuleNotFoundError(
+            """
+            LPIPS-TensorFlow required but not found.
+
+            Please install it by running the following command:
+            $ pip install git+http://github.com/alexlee-gk/lpips-tensorflow.git#egg=lpips_tf
+            """
+        ) from err
     # gray2rgb
     y_true = np.stack((y_true,) * 3, axis=-1)
     y_pred = np.stack((y_pred,) * 3, axis=-1)
 
-    image0_ph = tf.placeholder(tf.float32)
-    image1_ph = tf.placeholder(tf.float32)
+    image0_ph = tf.Variable(tf.float32)  # noqa: F841
+    image1_ph = tf.Variable(tf.float32)  # noqa: F841
 
-    distance_t = lpips_tf.lpips(image0_ph, image1_ph, model=model, net=net)
+    @tf.function
+    def lpips(image0_ph, image1_ph):
+        return lpips_tf.lpips(image0_ph, image1_ph, model=model, net=net)
 
-    with tf.Session() as session:
-        pl = session.run(distance_t, feed_dict={image0_ph: y_true, image1_ph: y_pred})
+    pl = lpips(y_true, y_pred)
 
     tf.reset_default_graph()
 
@@ -1108,7 +1107,7 @@ def tre_kp(y_true, y_pred, weighted=False):
 
     References
     ----------
-    .. [1] https://anhir.grand-challenge.org/Performance_Metrics/
+    .. https://anhir.grand-challenge.org/Performance_Metrics/
 
     """
     # Extract useful parameters
@@ -1154,7 +1153,7 @@ def rtre_kp(y_true, y_pred, h, w, weighted=False):
 
     References
     ----------
-    .. [1] https://anhir.grand-challenge.org/Performance_Metrics/
+    .. https://anhir.grand-challenge.org/Performance_Metrics/
 
     """
     # Extract useful parameters
